==> agora-0.0.22.tar.gz: agora-0.0.22/setup.py <==
###############################################################################
#
#   Agora Portfolio & Risk Management System
#
#   Copyright 2015 Carlo Sbraccia
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
###############################################################################

# FIXME: distutils problem with hardlinks
import os
del os.link

from setuptools import setup, find_packages

install_requires = [
    "onyx",
    "apscheduler",
    "argh",
    "numpy",
    "scipy",
    "matplotlib",
    "tornado",
    "sqlalchemy",
]

setup(
    name="agora",
    setup_requires=["hgtools"],
    use_vcs_version={"increment": "0.1"},
    description="A portfolio and risk management system based on onyx.",
    author="carlo sbraccia",
    author_email="carlo.sbraccia@yahoo.co.uk",
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=install_requires,
    entry_points={
        "console_scripts": [
        ],
    },
)

==> agora-0.1.1.tar.gz: agora-0.1.1/setup.py <==
###############################################################################
#
#   Agora Portfolio & Risk Management System
#
#   Copyright 2015 Carlo Sbraccia
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
###############################################################################

# FIXME: distutils problem with hardlinks
import os
del os.link

from setuptools import setup, find_packages

install_requires = [
    "onyx",
    "apscheduler",
    "argh",
    "numpy",
    "scipy",
    "matplotlib",
    "tornado",
    "sqlalchemy",
]

setup(
    name="agora",
    setup_requires=["hgtools"],
    use_vcs_version={"increment": "0.1"},
    description="A portfolio and risk management system based on onyx.",
    author="carlo sbraccia",
    author_email="carlosbraccia@yahoo.co.uk",
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=install_requires,
    entry_points={
        "console_scripts": [
            "risk-RESTServer = agora.risk.restful_webserver:main",
        ],
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: Financial and Insurance Industry",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.4",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
    ],
)
